bread.contrib package
=====================

.. automodule:: bread.contrib
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib.reports
   bread.contrib.workflows
